@@ -35,6 +35,7 @@ extern "C" {
 
 #define INTERP_METHOD_LINEAR 1
 #define INTERP_METHOD_PCHIP 2
+#define INTERP_METHOD_MRST 3
 
 /*
 **  Prototypes:
@@ -228,6 +229,8 @@ DECLSPEC extern double gsw_rho_t_exact(double sa, double t, double p);
 DECLSPEC extern void   gsw_rr68_interp_sa_ct(double *sa, double *ct, double *p, int mp,
                 double *p_i, int mp_i, double *sa_i, double *ct_i);
 DECLSPEC extern double gsw_saar(double p, double lon, double lat);
+DECLSPEC extern int    gsw_sa_ct_interp(double *sa, double *ct, double *p,
+                int m, double *p_i, int m_i, double *sa_i, double *ct_i);
 DECLSPEC extern double gsw_sa_freezing_estimate(double p, double saturation_fraction,
                 double *ct, double *t);
 DECLSPEC extern double gsw_sa_freezing_from_ct(double ct, double p,
@@ -297,11 +300,14 @@ DECLSPEC extern double gsw_t_freezing_poly(double sa, double p,
 DECLSPEC extern double gsw_t_from_ct(double sa, double ct, double p);
 DECLSPEC extern double gsw_t_from_pt0_ice(double pt0_ice, double p);
 DECLSPEC extern double gsw_thermobaric(double sa, double ct, double p);
+DECLSPEC extern int    gsw_tracer_ct_interp(double *tracer, double *ct, double *p,
+                int m, double *p_i, int m_i, double factor, double *sa_i, double *ct_i);
 DECLSPEC extern void   gsw_turner_rsubrho(double *sa, double *ct, double *p, int nz,
                 double *tu, double *rsubrho, double *p_mid);
 DECLSPEC extern int    gsw_util_indx(double *x, int n, double z);
 DECLSPEC extern double *gsw_util_interp1q_int(int nx, double *x, int *iy, int nxi,
                 double *x_i, double *y_i);
+DECLSPEC extern int    gsw_util_intersect(double *x, int nx, double *y, int ny, int *ix, int *iy);
 DECLSPEC extern double *gsw_util_linear_interp(int nx, double *x, int ny, double *y,
                 int nxi, double *x_i, double *y_i);
 DECLSPEC extern void   gsw_util_sort_real(double *rarray, int nx, int *iarray);
