@@ -5,3 +5,7 @@
     "geostrophic streamfunction dynamic height"},
 {"util_pchip_interp", util_pchip_interp, METH_VARARGS,
     "PCHIP interpolation"},
+{"sa_ct_interp", sa_ct_interp, METH_VARARGS,
+    "SA and CT interpolation"},
+{"tracer_ct_interp", tracer_ct_interp, METH_VARARGS,
+    "Tracer and CT interpolation"},
